@@ -442,6 +442,7 @@ namespace Breeze
     {
         // TODO: optimize based on repaintRegion
         auto c = client().data();
+        auto s = settings();
 
         // paint background
         if( !c->isShaded() )
@@ -455,11 +456,27 @@ namespace Breeze
             // clip away the top part
             if( !hideTitleBar() ) painter->setClipRect(0, borderTop(), size().width(), size().height() - borderTop(), Qt::IntersectClip);
 
-            painter->drawRoundedRect(rect(), Metrics::Frame_FrameRadius, Metrics::Frame_FrameRadius);
+            if( s->isAlphaChannelSupported() ) painter->drawRoundedRect(rect(), Metrics::Frame_FrameRadius, Metrics::Frame_FrameRadius);
+            else painter->drawRect( rect() );
+
             painter->restore();
         }
 
         if( !hideTitleBar() ) paintTitleBar(painter, repaintRegion);
+
+        if( hasBorders() && !s->isAlphaChannelSupported() )
+        {
+            painter->save();
+            painter->setRenderHint(QPainter::Antialiasing, false);
+            painter->setBrush( Qt::NoBrush );
+            painter->setPen( c->isActive() ?
+                c->color( ColorGroup::Active, ColorRole::TitleBar ):
+                c->color( ColorGroup::Inactive, ColorRole::Foreground ) );
+
+            painter->drawRect( rect().adjusted( 0, 0, -1, -1 ) );
+            painter->restore();
+        }
+
     }
 
     //________________________________________________________________
@@ -487,7 +504,8 @@ namespace Breeze
 
         }
 
-        if (isMaximized())
+        auto s = settings();
+        if( isMaximized() || !s->isAlphaChannelSupported() )
         {
 
             painter->drawRect(titleRect);
@@ -504,8 +522,6 @@ namespace Breeze
 
         }
 
-        auto s = settings();
-
         const QColor outlineColor( this->outlineColor() );
         if( !c->isShaded() && outlineColor.isValid() )
         {
@@ -654,17 +670,17 @@ namespace Breeze
             // contrast pixel
             QRectF innerRect = QRectF(
                 g_shadowSize - shadowOffset - Metrics::Shadow_Overlap, g_shadowSize - shadowOffset - Metrics::Shadow_Overlap,
-                shadowOffset + 2*Metrics::Shadow_Overlap,shadowOffset + 2*Metrics::Shadow_Overlap );
+                shadowOffset + 2*Metrics::Shadow_Overlap, shadowOffset + 2*Metrics::Shadow_Overlap );
 
             painter.setPen( gradientStopColor( g_shadowColor, g_shadowStrength*0.5 ) );
             painter.setBrush( Qt::NoBrush );
-            painter.drawRoundedRect( innerRect, 2.5, 2.5 );
+            painter.drawRoundedRect( innerRect, -0.5 + Metrics::Frame_FrameRadius, -0.5 + Metrics::Frame_FrameRadius );
 
             // mask out inner rect
             painter.setPen( Qt::NoPen );
             painter.setBrush( Qt::black );
             painter.setCompositionMode(QPainter::CompositionMode_DestinationOut );
-            painter.drawRoundedRect( innerRect, 3.0, 3.0 );
+            painter.drawRoundedRect( innerRect, 0.5 + Metrics::Frame_FrameRadius, 0.5 + Metrics::Frame_FrameRadius );
 
             painter.end();
 
