@@ -395,6 +395,9 @@ namespace Breeze
         */
         bool isSelectedItem( const QWidget*, const QPoint& ) const;
 
+        //* return true if option corresponds to QtQuick control
+        bool isQtQuickControl( const QStyleOption*, const QWidget* ) const;
+
         //@}
 
         //* adjust rect based on provided margins
@@ -454,6 +457,12 @@ namespace Breeze
         //* return true if one of the widget's parent inherits requested type
         template<typename T> bool hasParent( const QWidget* ) const;
 
+        //* return true if icons should be shown in menus
+        bool showIconsInMenuItems( void ) const;
+
+        //* return true if icons should be shown on buttons
+        bool showIconsOnPushButtons( void ) const;
+
         //* return true if passed widget is a menu title (KMenu::addTitle)
         bool isMenuTitle( const QWidget* ) const;
 
